@@ -32,19 +32,20 @@ import six
 
 from keystoneauth1 import access
 from keystoneauth1 import adapter
-from keystoneauth1.identity import base
 from keystoneauth1 import discover
+from keystoneauth1.identity import base
 from oslo_utils import encodeutils
 from oslo_utils import importutils
 from oslo_utils import strutils
 osprofiler_web = importutils.try_import("osprofiler.web")  # noqa
 import requests
+from six.moves import urllib
 import six.moves.urllib.parse as urlparse
 
+from cinderclient._i18n import _
 from cinderclient import api_versions
 from cinderclient import exceptions
 import cinderclient.extension
-from cinderclient._i18n import _
 
 try:
     from eventlet import sleep
@@ -78,21 +79,46 @@ def get_server_version(url):
     :returns: APIVersion object for min and max version supported by
               the server
     """
+    min_version = "2.0"
+    current_version = "2.0"
 
     logger = logging.getLogger(__name__)
     try:
-        scheme, netloc, path, query, frag = urlparse.urlsplit(url)
-        response = requests.get(scheme + '://' + netloc)
+        u = urllib.parse.urlparse(url)
+        version_url = None
+
+        # NOTE(andreykurilin): endpoint URL has at least 2 formats:
+        #   1. The classic (legacy) endpoint:
+        #       http://{host}:{optional_port}/v{1 or 2 or 3}/{project-id}
+        #       http://{host}:{optional_port}/v{1 or 2 or 3}
+        #   3. Under wsgi:
+        #       http://{host}:{optional_port}/volume/v{1 or 2 or 3}
+        for ver in ['v1', 'v2', 'v3']:
+            if u.path.endswith(ver) or "/{0}/".format(ver) in u.path:
+                path = u.path[:u.path.rfind(ver)]
+                version_url = '%s://%s%s' % (u.scheme, u.netloc, path)
+                break
+
+        if not version_url:
+            # NOTE(andreykurilin): probably, it is one of the next cases:
+            #  * https://volume.example.com/
+            #  * https://example.com/volume
+            # leave as is without cropping.
+            version_url = url
+
+        response = requests.get(version_url)
         data = json.loads(response.text)
         versions = data['versions']
         for version in versions:
             if '3.' in version['version']:
-                return (api_versions.APIVersion(version['min_version']),
-                        api_versions.APIVersion(version['version']))
+                min_version = version['min_version']
+                current_version = version['version']
+                break
     except exceptions.ClientException as e:
         logger.warning("Error in server version query:%s\n"
                        "Returning APIVersion 2.0", six.text_type(e.message))
-        return api_versions.APIVersion("2.0"), api_versions.APIVersion("2.0")
+    return (api_versions.APIVersion(min_version),
+            api_versions.APIVersion(current_version))
 
 
 def get_highest_client_server_version(url):
@@ -149,6 +175,9 @@ class SessionClient(adapter.LegacyJsonAdapter):
         if raise_exc and resp.status_code >= 400:
             raise exceptions.from_response(resp, body)
 
+        if not self.global_request_id:
+            self.global_request_id = resp.headers.get('x-openstack-request-id')
+
         return resp, body
 
     def _cs_request(self, url, method, **kwargs):
@@ -188,7 +217,7 @@ class SessionClient(adapter.LegacyJsonAdapter):
             version = get_volume_api_from_url(self.get_endpoint())
         except exceptions.UnsupportedVersion as e:
             msg = (_("Service catalog returned invalid url.\n"
-                     "%s") % six.text_type(e.message))
+                     "%s") % six.text_type(e))
             raise exceptions.UnsupportedVersion(msg)
 
         return version
@@ -439,10 +468,10 @@ class HTTPClient(object):
             if self.management_url == self.bypass_url:
                 msg = (_("Invalid url was specified in --os-endpoint or "
                          "environment variable CINDERCLIENT_BYPASS_URL.\n"
-                         "%s") % six.text_type(e.message))
+                         "%s") % six.text_type(e))
             else:
                 msg = (_("Service catalog returned invalid url.\n"
-                         "%s") % six.text_type(e.message))
+                         "%s") % six.text_type(e))
 
             raise exceptions.UnsupportedVersion(msg)
 
