@@ -1,4 +1,3 @@
-
 # Copyright 2011-2014 OpenStack Foundation
 # All Rights Reserved.
 #
@@ -25,32 +24,32 @@ import getpass
 import logging
 import sys
 
+from keystoneauth1 import discover
+from keystoneauth1 import exceptions
+from keystoneauth1.identity import v2 as v2_auth
+from keystoneauth1.identity import v3 as v3_auth
+from keystoneauth1 import loading
+from keystoneauth1 import session
+from oslo_utils import encodeutils
+from oslo_utils import importutils
+osprofiler_profiler = importutils.try_import("osprofiler.profiler")  # noqa
 import requests
 import six
+import six.moves.urllib.parse as urlparse
 
+import cinderclient
+from cinderclient import _i18n
+from cinderclient._i18n import _
 from cinderclient import api_versions
 from cinderclient import client
 from cinderclient import exceptions as exc
 from cinderclient import utils
-import cinderclient.auth_plugin
-from cinderclient._i18n import _
 
-from keystoneauth1 import discover
-from keystoneauth1 import loading
-from keystoneauth1 import session
-from keystoneauth1.identity import v2 as v2_auth
-from keystoneauth1.identity import v3 as v3_auth
-from keystoneauth1.exceptions import DiscoveryFailure
-import six.moves.urllib.parse as urlparse
-from oslo_utils import encodeutils
-from oslo_utils import importutils
 
-osprofiler_profiler = importutils.try_import("osprofiler.profiler")
-
-from cinderclient import _i18n
 # Enable i18n lazy translation
 _i18n.enable_lazy()
 
+
 DEFAULT_MAJOR_OS_VOLUME_API_VERSION = "3"
 DEFAULT_CINDER_ENDPOINT_TYPE = 'publicURL'
 V1_SHELL = 'cinderclient.v1.shell'
@@ -139,12 +138,20 @@ class OpenStackCinderShell(object):
                             help=_('Shows debugging output.'))
 
         parser.add_argument('--os-auth-system',
-                            metavar='<auth-system>',
+                            metavar='<os-auth-system>',
+                            dest='os_auth_type',
                             default=utils.env('OS_AUTH_SYSTEM'),
-                            help=_('Defaults to env[OS_AUTH_SYSTEM].'))
+                            help=_('DEPRECATED! Use --os-auth-type. '
+                                   'Defaults to env[OS_AUTH_SYSTEM].'))
         parser.add_argument('--os_auth_system',
                             help=argparse.SUPPRESS)
-
+        parser.add_argument('--os-auth-type',
+                            metavar='<os-auth-type>',
+                            dest='os_auth_type',
+                            default=utils.env('OS_AUTH_TYPE'),
+                            help=_('Defaults to env[OS_AUTH_TYPE].'))
+        parser.add_argument('--os_auth_type',
+                            help=argparse.SUPPRESS)
         parser.add_argument('--service-type',
                             metavar='<service-type>',
                             help=_('Service type. '
@@ -201,14 +208,26 @@ class OpenStackCinderShell(object):
 
         parser.add_argument('--bypass-url',
                             metavar='<bypass-url>',
-                            dest='bypass_url',
-                            default=utils.env('CINDERCLIENT_BYPASS_URL'),
-                            help=_("Use this API endpoint instead of the "
+                            dest='os_endpoint',
+                            default=utils.env('CINDERCLIENT_BYPASS_URL',
+                            default=utils.env('CINDER_ENDPOINT')),
+                            help=_("DEPRECATED! Use os_endpoint. "
+                            "Use this API endpoint instead of the "
                             "Service Catalog. Defaults to "
                             "env[CINDERCLIENT_BYPASS_URL]."))
         parser.add_argument('--bypass_url',
                             help=argparse.SUPPRESS)
 
+        parser.add_argument('--os-endpoint',
+                            metavar='<os-endpoint>',
+                            dest='os_endpoint',
+                            default=utils.env('CINDER_ENDPOINT'),
+                            help=_("Use this API endpoint instead of the "
+                            "Service Catalog. Defaults to "
+                            "env[CINDER_ENDPOINT]."))
+        parser.add_argument('--os_endpoint',
+                            help=argparse.SUPPRESS)
+
         parser.add_argument('--retries',
                             metavar='<retries>',
                             type=int,
@@ -218,20 +237,18 @@ class OpenStackCinderShell(object):
         if osprofiler_profiler:
             parser.add_argument('--profile',
                                 metavar='HMAC_KEY',
+                                default=utils.env('OS_PROFILE'),
                                 help=_('HMAC key to use for encrypting '
                                 'context data for performance profiling '
                                 'of operation. This key needs to match the '
                                 'one configured on the cinder api server. '
                                 'Without key the profiling will not be '
                                 'triggered even if osprofiler is enabled '
-                                'on server side.'))
+                                'on server side. Defaults to '
+                                'env[OS_PROFILE].'))
 
         self._append_global_identity_args(parser)
 
-        # The auth-system-plugins might require some extra options
-        cinderclient.auth_plugin.discover_auth_systems()
-        cinderclient.auth_plugin.load_auth_system_opts(parser)
-
         return parser
 
     def _append_global_identity_args(self, parser):
@@ -440,7 +457,7 @@ class OpenStackCinderShell(object):
             msg = (_(" (Supported by API version %(start)s and later)")
                 % {"start": start_version.get_string()})
         else:
-            msg = (_(" Supported until API version %(end)s)")
+            msg = (_(" (Supported until API version %(end)s)")
                 % {"end": end_version.get_string()})
         return six.text_type(msg)
 
@@ -609,18 +626,23 @@ class OpenStackCinderShell(object):
 
         (os_username, os_password, os_tenant_name, os_auth_url,
          os_region_name, os_tenant_id, endpoint_type,
-         service_type, service_name, volume_service_name, bypass_url,
-         cacert, os_auth_system) = (
+         service_type, service_name, volume_service_name, os_endpoint,
+         cacert, os_auth_type) = (
              args.os_username, args.os_password,
              args.os_tenant_name, args.os_auth_url,
              args.os_region_name, args.os_tenant_id,
              args.os_endpoint_type,
              args.service_type, args.service_name,
              args.volume_service_name,
-             args.bypass_url, args.os_cacert,
-             args.os_auth_system)
-        if os_auth_system and os_auth_system != "keystone":
-            auth_plugin = cinderclient.auth_plugin.load_plugin(os_auth_system)
+             args.os_endpoint, args.os_cacert,
+             args.os_auth_type)
+        auth_session = None
+
+        if os_auth_type and os_auth_type != "keystone":
+            auth_plugin = loading.load_auth_from_argparse_arguments(
+                self.options)
+            auth_session = loading.load_session_from_argparse_arguments(
+                self.options, auth=auth_plugin)
         else:
             auth_plugin = None
 
@@ -638,16 +660,10 @@ class OpenStackCinderShell(object):
                                    self.options.os_project_domain_id)) or
                                  self.options.os_project_id)
 
-        if not utils.isunauthenticated(args.func):
-            if auth_plugin:
-                auth_plugin.parse_opts(args)
-
-            if not auth_plugin or not auth_plugin.opts:
-                if not os_username:
-                    raise exc.CommandError("You must provide a user name "
-                                           "through --os-username or "
-                                           "env[OS_USERNAME].")
-
+        # NOTE(e0ne): if auth_session exists it means auth plugin created
+        # session and we don't need to check for password and other
+        # authentification-related things.
+        if not utils.isunauthenticated(args.func) and not auth_session:
             if not os_password:
                 # No password, If we've got a tty, try prompting for it
                 if hasattr(sys.stdin, 'isatty') and sys.stdin.isatty():
@@ -682,10 +698,6 @@ class OpenStackCinderShell(object):
                     "(env[OS_PROJECT_DOMAIN_NAME])"
                 ))
 
-            if not os_auth_url:
-                if os_auth_system and os_auth_system != 'keystone':
-                    os_auth_url = auth_plugin.get_auth_url()
-
             if not os_auth_url:
                 raise exc.CommandError(
                     "You must provide an authentication URL "
@@ -706,13 +718,12 @@ class OpenStackCinderShell(object):
                 "(env[OS_PROJECT_DOMAIN_NAME])"
             ))
 
-        if not os_auth_url:
+        if not os_auth_url and not auth_plugin:
             raise exc.CommandError(
                 "You must provide an authentication URL "
                 "through --os-auth-url or env[OS_AUTH_URL].")
 
-        auth_session = None
-        if not auth_plugin:
+        if not auth_session:
             auth_session = self._get_keystone_session()
 
         insecure = self.options.insecure
@@ -727,11 +738,11 @@ class OpenStackCinderShell(object):
             service_type=service_type,
             service_name=service_name,
             volume_service_name=volume_service_name,
-            bypass_url=bypass_url,
+            bypass_url=os_endpoint,
             retries=options.retries,
             http_log_debug=args.debug,
             insecure=insecure,
-            cacert=cacert, auth_system=os_auth_system,
+            cacert=cacert, auth_system=os_auth_type,
             auth_plugin=auth_plugin,
             session=auth_session,
             logger=self.ks_logger if auth_session else self.client_logger)
@@ -819,10 +830,9 @@ class OpenStackCinderShell(object):
 
         username = self.options.os_username
         password = self.options.os_password
-        tenant_id = (self.options.os_tenant_id
-                     or self.options.os_project_id)
-        tenant_name = (self.options.os_tenant_name
-                       or self.options.os_project_name)
+        tenant_id = self.options.os_tenant_id or self.options.os_project_id
+        tenant_name = (self.options.os_tenant_name or
+                       self.options.os_project_name)
 
         return v2_auth.Password(
             v2_auth_url,
@@ -839,8 +849,8 @@ class OpenStackCinderShell(object):
         user_domain_id = self.options.os_user_domain_id
         password = self.options.os_password
         project_id = self.options.os_project_id or self.options.os_tenant_id
-        project_name = (self.options.os_project_name
-                        or self.options.os_tenant_name)
+        project_name = (self.options.os_project_name or
+                        self.options.os_tenant_name)
         project_domain_name = self.options.os_project_domain_name
         project_domain_id = self.options.os_project_domain_id
 
@@ -866,7 +876,7 @@ class OpenStackCinderShell(object):
             ks_discover = discover.Discover(session=session, url=auth_url)
             v2_auth_url = ks_discover.url_for('2.0')
             v3_auth_url = ks_discover.url_for('3.0')
-        except DiscoveryFailure:
+        except exceptions.DiscoveryFailure:
             # Discovery response mismatch. Raise the error
             raise
         except Exception:
