@@ -28,7 +28,9 @@ REQUEST_ID = 'req-test-request-id'
 def _stub_volume(*args, **kwargs):
     volume = {
         "migration_status": None,
-        "attachments": [{u'server_id': u'1234'}],
+        "attachments": [{u'server_id': u'1234',
+                         u'id': u'3f88836f-adde-4296-9f6b-2c59a0bcda9a',
+                         u'attachment_id': u'5678'}],
         "links": [
             {
                 "href": "http://localhost/v2/fake/volumes/1234",
@@ -535,6 +537,8 @@ class FakeHTTPClient(base_client.HTTPClient):
         elif action == 'os-volume_upload_image':
             assert 'image_name' in body[action]
             _body = body
+        elif action == 'revert':
+            assert 'snapshot_id' in body[action]
         else:
             raise AssertionError("Unexpected action: %s" % action)
         return (resp, {}, _body)
@@ -625,7 +629,6 @@ class FakeHTTPClient(base_client.HTTPClient):
                           'gigabytes': 1,
                           'backups': 1,
                           'backup_gigabytes': 1,
-                          'consistencygroups': 1,
                           'per_volume_gigabytes': 1, }})
 
     def get_os_quota_sets_test_defaults(self):
@@ -637,7 +640,6 @@ class FakeHTTPClient(base_client.HTTPClient):
                           'gigabytes': 1,
                           'backups': 1,
                           'backup_gigabytes': 1,
-                          'consistencygroups': 1,
                           'per_volume_gigabytes': 1, }})
 
     def put_os_quota_sets_test(self, body, **kw):
@@ -652,7 +654,6 @@ class FakeHTTPClient(base_client.HTTPClient):
                           'gigabytes': 1,
                           'backups': 1,
                           'backup_gigabytes': 1,
-                          'consistencygroups': 2,
                           'per_volume_gigabytes': 1, }})
 
     def delete_os_quota_sets_1234(self, **kw):
@@ -668,13 +669,11 @@ class FakeHTTPClient(base_client.HTTPClient):
     def get_os_quota_class_sets_test(self, **kw):
         return (200, {}, {'quota_class_set': {
                           'class_name': 'test',
-                          'metadata_items': [],
                           'volumes': 1,
                           'snapshots': 1,
                           'gigabytes': 1,
                           'backups': 1,
                           'backup_gigabytes': 1,
-                          'consistencygroups': 1,
                           'per_volume_gigabytes': 1, }})
 
     def put_os_quota_class_sets_test(self, body, **kw):
@@ -683,13 +682,11 @@ class FakeHTTPClient(base_client.HTTPClient):
                               required=['class_name'])
         return (200, {}, {'quota_class_set': {
                           'class_name': 'test',
-                          'metadata_items': [],
                           'volumes': 2,
                           'snapshots': 2,
                           'gigabytes': 1,
                           'backups': 1,
                           'backup_gigabytes': 1,
-                          'consistencygroups': 2,
                           'per_volume_gigabytes': 1}})
 
     #
