@@ -13,21 +13,22 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import ddt
 import fixtures
 import mock
-import ddt
 from requests_mock.contrib import fixture as requests_mock_fixture
 from six.moves.urllib import parse
 
 from cinderclient import client
 from cinderclient import exceptions
 from cinderclient import shell
-from cinderclient.v2 import volumes
-from cinderclient.v2 import volume_backups
 from cinderclient.v2 import shell as test_shell
+from cinderclient.v2 import volume_backups
+from cinderclient.v2 import volumes
+
+from cinderclient.tests.unit.fixture_data import keystone_client
 from cinderclient.tests.unit import utils
 from cinderclient.tests.unit.v2 import fakes
-from cinderclient.tests.unit.fixture_data import keystone_client
 
 
 @ddt.ddt
@@ -1407,3 +1408,20 @@ class ShellTest(utils.TestCase):
                          '--backup-gigabytes 1 '
                          '--per-volume-gigabytes 1')
         self.assert_called('PUT', '/os-quota-class-sets/test', body=expected)
+
+    def test_translate_attachments(self):
+        attachment_id = 'aaaa'
+        server_id = 'bbbb'
+        obj_id = 'cccc'
+        info = {
+            'attachments': [{
+                'attachment_id': attachment_id,
+                'id': obj_id,
+                'server_id': server_id}]
+            }
+
+        new_info = test_shell._translate_attachments(info)
+
+        self.assertEqual(attachment_id, new_info['attachment_ids'][0])
+        self.assertEqual(server_id, new_info['attached_servers'][0])
+        self.assertNotIn('id', new_info)
