@@ -15,31 +15,33 @@
 
 import logging
 
-from cinderclient import client
 from cinderclient import api_versions
+from cinderclient import client
+from cinderclient.v3 import attachments
 from cinderclient.v3 import availability_zones
+from cinderclient.v3 import capabilities
 from cinderclient.v3 import cgsnapshots
 from cinderclient.v3 import clusters
 from cinderclient.v3 import consistencygroups
-from cinderclient.v3 import capabilities
-from cinderclient.v3 import groups
 from cinderclient.v3 import group_snapshots
 from cinderclient.v3 import group_types
+from cinderclient.v3 import groups
 from cinderclient.v3 import limits
 from cinderclient.v3 import messages
 from cinderclient.v3 import pools
 from cinderclient.v3 import qos_specs
 from cinderclient.v3 import quota_classes
 from cinderclient.v3 import quotas
+from cinderclient.v3 import resource_filters
 from cinderclient.v3 import services
-from cinderclient.v3 import volumes
-from cinderclient.v3 import volume_snapshots
-from cinderclient.v3 import volume_types
-from cinderclient.v3 import volume_type_access
-from cinderclient.v3 import volume_encryption_types
 from cinderclient.v3 import volume_backups
 from cinderclient.v3 import volume_backups_restore
+from cinderclient.v3 import volume_encryption_types
+from cinderclient.v3 import volume_snapshots
 from cinderclient.v3 import volume_transfers
+from cinderclient.v3 import volume_type_access
+from cinderclient.v3 import volume_types
+from cinderclient.v3 import volumes
 
 
 class Client(object):
@@ -60,7 +62,7 @@ class Client(object):
                  proxy_tenant_id=None, proxy_token=None, region_name=None,
                  endpoint_type='publicURL', extensions=None,
                  service_type='volumev3', service_name=None,
-                 volume_service_name=None, bypass_url=None, retries=None,
+                 volume_service_name=None, bypass_url=None, retries=0,
                  http_log_debug=False, cacert=None, auth_system='keystone',
                  auth_plugin=None, session=None, api_version=None,
                  logger=None, **kwargs):
@@ -71,7 +73,6 @@ class Client(object):
         self.limits = limits.LimitsManager(self)
         self.api_version = api_version or api_versions.APIVersion(self.version)
 
-        # extensions
         self.volumes = volumes.VolumeManager(self)
         self.volume_snapshots = volume_snapshots.SnapshotManager(self)
         self.volume_types = volume_types.VolumeTypeManager(self)
@@ -85,6 +86,7 @@ class Client(object):
         self.quotas = quotas.QuotaSetManager(self)
         self.backups = volume_backups.VolumeBackupManager(self)
         self.messages = messages.MessageManager(self)
+        self.resource_filters = resource_filters.ResourceFilterManager(self)
         self.restores = volume_backups_restore.VolumeBackupRestoreManager(self)
         self.transfers = volume_transfers.VolumeTransferManager(self)
         self.services = services.ServiceManager(self)
@@ -98,6 +100,8 @@ class Client(object):
             availability_zones.AvailabilityZoneManager(self)
         self.pools = pools.PoolManager(self)
         self.capabilities = capabilities.CapabilitiesManager(self)
+        self.attachments = \
+            attachments.VolumeAttachmentManager(self)
 
         # Add in any extensions...
         if extensions:
